Package

Struct Package 

pub struct Package {
    pub namespace: String,
    pub name: String,
    pub version: String,
    pub primary_language: String,
    pub license_expression: String,
    pub declared_license: String,
    pub dependencies: Vec<DependentPackage>,
}
A package object as represented by either data from one of its different types of package manifests or that of a package instance created from one or more of these package manifests, and files for that package.

Fields

namespace: String

Optional namespace for this package.

name: String

The name of this package.

version: String

Optional version of this package.

primary_language: String

Primary programming language

license_expression: String

The license expression for this package typically derived from its declared license or from some other type-specific routine or convention.

declared_license: String

The declared license mention, tag or text as found in a package manifest. This can be a string, a list or dict of strings possibly nested, as found originally in the manifest.

dependencies: Vec<DependentPackage>

A list of DependentPackage for this package.