pub struct Package {
pub namespace: String,
pub name: String,
pub version: String,
pub primary_language: String,
pub license_expression: String,
pub declared_license: String,
pub dependencies: Vec<DependentPackage>,
}Expand description
A package object as represented by either data from one of its different types of package manifests or that of a package instance created from one or more of these package manifests, and files for that package.
Fields
namespace: StringOptional namespace for this package.
name: StringThe name of this package.
version: StringOptional version of this package.
primary_language: StringPrimary programming language
license_expression: StringThe license expression for this package typically derived from its declared license or from some other type-specific routine or convention.
declared_license: StringThe declared license mention, tag or text as found in a package manifest. This can be a string, a list or dict of strings possibly nested, as found originally in the manifest.
dependencies: Vec<DependentPackage>A list of DependentPackage for this package.